# Generated by roxygen2: do not edit by hand

export(aa_sub)
export(annotation_position)
export(annotation_range)
export(annotation_variant)
export(clinvar_variants)
export(concat)
export(create_A3)
export(gene2sequence)
export(get_alphafold)
export(pdb_annotations)
export(read_A3json)
export(uniprot_sequence)
export(uniprot_to_A3)
export(write_A3json)
import(S7)
import(cli)
import(data.table)
import(rtemis.core)
import(utils)
importFrom(grDevices,col2rgb)
importFrom(stats,ave)
importFrom(stats,na.exclude)
