#' \pkg{rtemis.a3}: Amino Acid Annotation format
#'
#' @name rtemis.a3-package
#'
#' @title rtemis.a3: Amino Acid Annotation format
#'
#' @description
#' Amino Acid Annotation format utilities
#'
#' @import cli data.table rtemis.core S7 utils
#' @importFrom stats na.exclude ave
#' @importFrom grDevices col2rgb
"_PACKAGE"

NULL
