% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/utils_uniprot.R
\name{uniprot_sequence}
\alias{uniprot_sequence}
\title{Fetch a protein sequence from UniProt}
\usage{
uniprot_sequence(
  accession,
  base_url = "https://rest.uniprot.org/uniprotkb",
  verbosity = 1L
)
}
\arguments{
\item{accession}{Character scalar: UniProt accession, e.g. \code{"P10636"}.}

\item{base_url}{Character scalar: UniProt REST API base URL.}

\item{verbosity}{Integer scalar: Verbosity level.}
}
\value{
Character scalar: amino acid sequence in single-letter code.
}
\description{
Lightweight FASTA-only fetch. Use this when you only need the amino acid
sequence. For full annotations and metadata use \code{\link[=uniprot_to_A3]{uniprot_to_A3()}}.
}
\examples{
# Requires internet connection and fetches data from UniProt.
\dontrun{
  seq <- uniprot_sequence("P10636")
}
}
\author{
EDG
}
