% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/a3.R
\name{create_A3}
\alias{create_A3}
\title{Create an A3 object from sequence, annotations, and metadata}
\usage{
create_A3(
  sequence,
  site = list(),
  region = list(),
  ptm = list(),
  processing = list(),
  variant = list(),
  uniprot_id = NULL,
  description = NULL,
  reference = NULL,
  organism = NULL
)
}
\arguments{
\item{sequence}{Character scalar: Amino acid sequence string.}

\item{site}{Named list of site annotations}

\item{region}{Named list of region annotations}

\item{ptm}{Named list of PTM annotations}

\item{processing}{Named list of processing annotations}

\item{variant}{Named list of variant annotations}

\item{uniprot_id}{Optional character scalar: UniProt accession.}

\item{description}{Optional character scalar: Protein description.}

\item{reference}{Optional character scalar: Citation or URL.}

\item{organism}{Optional character scalar: Species name.}
}
\value{
A3 object
}
\description{
Create an A3 object from sequence, annotations, and metadata
}
\examples{
# Minimal: sequence only
a <- create_A3("MAEPRQEFEVMEDHAGTYGLGDRK")

# With site, region, and PTM annotations
a <- create_A3(
  "MAEPRQEFEVMEDHAGTYGLGDRK",
  site = list(
    Active_site = annotation_position(c(5L, 17L), type = "active site")
  ),
  region = list(
    Domain = annotation_range(rbind(c(3L, 10L), c(15L, 22L)),
      type = "repeat"
    )
  ),
  ptm = list(
    Phosphorylation = annotation_position(c(2L, 18L), type = "phosphoserine")
  ),
  uniprot_id = "P10636",
  organism = "Homo sapiens"
)
}
\author{
EDG
}
