% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/a3-package.R
\docType{package}
\name{rtemis.a3-package}
\alias{rtemis.a3}
\alias{rtemis.a3-package}
\title{rtemis.a3: Amino Acid Annotation format}
\description{
Amino Acid Annotation format utilities
}
\details{
\pkg{rtemis.a3}: Amino Acid Annotation format
}
\seealso{
Useful links:
\itemize{
  \item \url{https://a3.rtemis.org}
  \item Report bugs at \url{https://github.com/rtemis-org/a3/issues}
}

}
\author{
\strong{Maintainer}: E.D. Gennatas \email{gennatas@gmail.com} (\href{https://orcid.org/0000-0001-9280-3609}{ORCID}) [copyright holder]

}
