% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/a3.R
\name{annotation_range}
\alias{annotation_range}
\title{Create range-based annotations for A3}
\usage{
annotation_range(x, type = NULL)
}
\arguments{
\item{x}{Integer matrix with 2 columns corresponding to start and end positions of the
annotation (1-based indexing).}

\item{type}{Optional character scalar: Annotation type. \code{NULL} is treated as
the empty string in the canonical A3 representation.}
}
\value{
Named list with \code{index} (A3Range) and \code{type} (character)
}
\description{
Creates an annotation spec (named list) with an \code{A3Range} index and optional type,
for use with \code{create_A3()}.
}
\examples{
# Create a region annotation for ranges 3-10 and 15-22, of type "repeat"
annotation_range(rbind(c(3L, 10L), c(15L, 22L)), type = "repeat")
}
\author{
EDG
}
