% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/utils_a3.R
\name{aa_sub}
\alias{aa_sub}
\title{Perform amino acid substitutions}
\usage{
aa_sub(x, substitutions, verbosity = 1L)
}
\arguments{
\item{x}{Character vector: Amino acid sequence. e.g. \code{"ARND"} or
\code{c("A", "R", "N", "D")}.}

\item{substitutions}{Character vector: Substitutions to perform in the format
"OriginalPositionNew", e.g. \code{c("C291A", "C322A")}.}

\item{verbosity}{Integer: Verbosity level.}
}
\value{
Character vector with substitutions performed.
}
\description{
Perform amino acid substitutions
}
\examples{
aa_sub(c("A", "R", "N", "D"), c("R2K", "N3S"))
}
\author{
EDG
}
